==> nextcloud-24.0.10.tgz: nextcloud/apps/theming/l10n/en_GB.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "The given name is too long",
    "The given web address is too long" : "The given web address is too long",
    "The given web address is not a valid URL" : "The given web address is not a valid URL",
    "The given legal notice address is too long" : "The given legal notice address is too long",
    "The given legal notice address is not a valid URL" : "The given legal notice address is not a valid URL",
    "The given privacy policy address is too long" : "The given privacy policy address is too long",
    "The given privacy policy address is not a valid URL" : "The given privacy policy address is not a valid URL",
    "The given slogan is too long" : "The given slogan is too long",
    "The given color is invalid" : "The given colour is invalid",
    "Disable-user-theming should be true or false" : "Disable-user-theming should be true or false",
    "Saved" : "Saved",
    "The file was uploaded" : "The file was uploaded",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "No file uploaded" : "No file uploaded",
    "Failed to clean up the old administration theming images folder" : "Failed to clean up the old administration theming images folder",
    "Failed to clean up the old administration image folder" : "Failed to clean up the old administration image folder",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "You are already using a custom theme. Theming app settings might be overwritten by that.",
    "Theming" : "Theming",
    "Appearance and accessibility" : "Appearance and accessibility",
    "Dark theme with high contrast mode" : "Dark theme with high contrast mode",
    "Enable dark high contrast mode" : "Enable dark high contrast mode",
    "Similar to the high contrast mode, but with dark colours." : "Similar to the high contrast mode, but with dark colours.",
    "Dark theme" : "Dark theme",
    "Enable dark theme" : "Enable dark theme",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "A dark theme that is soothing for your eyes (by reducing the overall luminosity and brightness).",
    "System default theme" : "System default theme",
    "Enable the system default" : "Enable the system default",
    "Using the default system appearance." : "Using the default system appearance.",
    "Dyslexia font" : "Dyslexia font",
    "Enable dyslexia font" : "Enable dyslexia font",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia.",
    "High contrast mode" : "High contrast mode",
    "Enable high contrast mode" : "Enable high contrast mode",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased.",
    "Light theme" : "Light theme",
    "Enable the default light theme" : "Enable the default light theme",
    "The default light appearance." : "The default light appearance.",
    "Legal notice" : "Legal notice",
    "Privacy policy" : "Privacy policy",
    "Adjust the Nextcloud theme" : "Adjust the Nextcloud theme",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming makes it possible to easily customise the look and feel of your instance and supported clients. This will be visible for all users.",
    "Advanced options" : "Advanced options",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and colour.",
    "Name" : "Name",
    "Web link" : "Web link",
    "a safe home for all your data" : "a safe home for all your data",
    "Slogan" : "Slogan",
    "Color" : "Colour",
    "Logo" : "Logo",
    "Upload new logo" : "Upload new logo",
    "Background and login image" : "Background and login image",
    "Upload new background and login image" : "Upload new background and login image",
    "Legal notice link" : "Legal notice link",
    "Privacy policy link" : "Privacy policy link",
    "Header logo" : "Header logo",
    "Upload new header logo" : "Upload new header logo",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Upload new favicon",
    "User settings" : "User settings",
    "Disable user theming" : "Disable user theming",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on.",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
    "Disable all keyboard shortcuts" : "Disable all keyboard shortcuts",
    "Background" : "Background",
    "Customization has been disabled by your administrator" : "Customization has been disabled by your administrator",
    "Set a custom background" : "Set a custom background",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!",
    "Custom background" : "Custom background",
    "Default background" : "Default background",
    "Change color" : "Change colour",
    "Remove background" : "Remove background",
    "Select a background from your files" : "Select a background from your files",
    "Theme selection is enforced" : "Theme selection is enforced",
    "Select a custom color" : "Select a custom colour",
    "Reset to default" : "Reset to default",
    "Upload" : "Upload",
    "Remove background image" : "Remove background image",
    "Loading preview…" : "Loading preview…",
    "Admin" : "Admin",
    "Error uploading the file" : "Error uploading the file",
    "Name cannot be empty" : "Name cannot be empty",
    "Open documentation" : "Open documentation",
    "https://…" : "https://…",
    "Login image" : "Login image",
    "Upload new login background" : "Upload new login background",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and colour.",
    "Migrate and clean up admin theming images" : "Migrate and clean up admin theming images",
    "Failed to clean up the old admin theming images folder" : "Failed to clean up the old admin theming images folder",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
    "Pick from Files" : "Pick from Files",
    "Default image" : "Default image",
    "Custom color" : "Custom colour",
    "Plain background" : "Plain background",
    "Insert from {productName}" : "Insert from {productName}",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.7p0.tgz: nextcloud/apps/theming/l10n/en_GB.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "The given name is too long",
    "The given web address is too long" : "The given web address is too long",
    "The given web address is not a valid URL" : "The given web address is not a valid URL",
    "The given legal notice address is too long" : "The given legal notice address is too long",
    "The given legal notice address is not a valid URL" : "The given legal notice address is not a valid URL",
    "The given privacy policy address is too long" : "The given privacy policy address is too long",
    "The given privacy policy address is not a valid URL" : "The given privacy policy address is not a valid URL",
    "The given slogan is too long" : "The given slogan is too long",
    "The given color is invalid" : "The given colour is invalid",
    "Disable-user-theming should be true or false" : "Disable-user-theming should be true or false",
    "Saved" : "Saved",
    "The file was uploaded" : "The file was uploaded",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "No file uploaded" : "No file uploaded",
    "Failed to clean up the old administration theming images folder" : "Failed to clean up the old administration theming images folder",
    "Failed to clean up the old administration image folder" : "Failed to clean up the old administration image folder",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "You are already using a custom theme. Theming app settings might be overwritten by that.",
    "Theming" : "Theming",
    "Appearance and accessibility" : "Appearance and accessibility",
    "Dark theme with high contrast mode" : "Dark theme with high contrast mode",
    "Enable dark high contrast mode" : "Enable dark high contrast mode",
    "Similar to the high contrast mode, but with dark colours." : "Similar to the high contrast mode, but with dark colours.",
    "Dark theme" : "Dark theme",
    "Enable dark theme" : "Enable dark theme",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "A dark theme that is soothing for your eyes (by reducing the overall luminosity and brightness).",
    "System default theme" : "System default theme",
    "Enable the system default" : "Enable the system default",
    "Using the default system appearance." : "Using the default system appearance.",
    "Dyslexia font" : "Dyslexia font",
    "Enable dyslexia font" : "Enable dyslexia font",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia.",
    "High contrast mode" : "High contrast mode",
    "Enable high contrast mode" : "Enable high contrast mode",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased.",
    "Light theme" : "Light theme",
    "Enable the default light theme" : "Enable the default light theme",
    "The default light appearance." : "The default light appearance.",
    "Legal notice" : "Legal notice",
    "Privacy policy" : "Privacy policy",
    "Adjust the Nextcloud theme" : "Adjust the Nextcloud theme",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming makes it possible to easily customise the look and feel of your instance and supported clients. This will be visible for all users.",
    "Advanced options" : "Advanced options",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and colour.",
    "Name" : "Name",
    "Web link" : "Web link",
    "a safe home for all your data" : "a safe home for all your data",
    "Slogan" : "Slogan",
    "Color" : "Colour",
    "Logo" : "Logo",
    "Upload new logo" : "Upload new logo",
    "Background and login image" : "Background and login image",
    "Upload new background and login image" : "Upload new background and login image",
    "Legal notice link" : "Legal notice link",
    "Privacy policy link" : "Privacy policy link",
    "Header logo" : "Header logo",
    "Upload new header logo" : "Upload new header logo",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Upload new favicon",
    "User settings" : "User settings",
    "Disable user theming" : "Disable user theming",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on.",
    "Background" : "Background",
    "Customization has been disabled by your administrator" : "Customization has been disabled by your administrator",
    "Set a custom background" : "Set a custom background",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
    "Disable all keyboard shortcuts" : "Disable all keyboard shortcuts",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!",
    "Custom background" : "Custom background",
    "Default background" : "Default background",
    "Change color" : "Change colour",
    "No background" : "No background",
    "Select a background from your files" : "Select a background from your files",
    "Select background" : "Select background",
    "No background has been selected" : "No background has been selected",
    "Theme selection is enforced" : "Theme selection is enforced",
    "Select a custom color" : "Select a custom colour",
    "Reset to default" : "Reset to default",
    "Upload" : "Upload",
    "Remove background image" : "Remove background image",
    "Loading preview…" : "Loading preview…",
    "Admin" : "Admin",
    "Error uploading the file" : "Error uploading the file",
    "Name cannot be empty" : "Name cannot be empty",
    "Migrate and clean up admin theming images" : "Migrate and clean up admin theming images",
    "Failed to clean up the old admin theming images folder" : "Failed to clean up the old admin theming images folder",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
    "Pick from Files" : "Pick from Files",
    "Default image" : "Default image",
    "Custom color" : "Custom colour",
    "Plain background" : "Plain background",
    "Insert from {productName}" : "Insert from {productName}",
    "Open documentation" : "Open documentation",
    "https://…" : "https://…",
    "Upload new login background" : "Upload new login background",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and colour."
},
"nplurals=2; plural=(n != 1);");
